Codepages from Roman Czyborra
-----------------------------

These codepages were published by Roman Czyborra at http://czyborra.com/charsets/.

Currently accessible mirrors:
- http://aspell.net/charsets/
- https://web.archive.org/web/20210814032628/http://czyborra.com/charsets/


A description of the KOI Cyrillic charsets and their history is at
http://aspell.net/charsets/cyrillic.html.


Modifications
-------------

I have modified `viscii.txt` to replace codepoint `0xA6`.
This was given as `u+1EA8` _LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE_ but should be its
lowercase variant `u+1EA9`, with the uppercase already included at codepoint `0x86`.
